library animation_load_progress;

import 'package:flutter/material.dart';
import 'package:loading_indicator/loading_indicator.dart';

class AnimationLoadProgress extends StatelessWidget {
  final bool inAsyncCall;
  final double opacity;
  final Color color;
  final Widget progressIndicator;
  final Offset offset;
  final bool dismissible;
  final Widget child;
  final double size;
  final Color loadColor;

  const AnimationLoadProgress({
    Key? key,
    required this.inAsyncCall,
    this.opacity = 0.3,
    this.color = Colors.grey,
    this.progressIndicator = const CircularProgressIndicator(),
    required this.offset,
    this.dismissible = false,
    required this.child,
    this.size = 2,
    required this.loadColor,
  })  : assert(child != null),
        assert(inAsyncCall != null),
        super(key: key);

  @override
  Widget build(BuildContext context) {
    if (!inAsyncCall) return child;

    Widget layOutProgressIndicator;
    if (offset == null) {
      layOutProgressIndicator = Center(child: progressIndicator);
    } else {
      layOutProgressIndicator = Positioned(
        child: SizedBox(
          height: 50,
          width: 50,
          child: Center(
              child: LoadingIndicator(
            indicatorType: Indicator.ballRotateChase,
            colors: [loadColor],
            strokeWidth: 2,
          )),
        ),
        left: offset.dx,
        top: offset.dy,
      );
    }

    return Stack(
      children: [
        child,
        Opacity(
          child: ModalBarrier(dismissible: dismissible, color: color),
          opacity: opacity,
        ),
        layOutProgressIndicator,
      ],
    );
  }
}
